@@ -1,3 +1,5 @@
+from __future__ import print_function
+
 import compileall
 from optparse import make_option
 import os
@@ -9,8 +11,8 @@ from django.core.management.base import BaseCommand
 class Command(BaseCommand):
     help = \
         """
-    Compiles .pyc files in the project.
-    """
+        Compiles .pyc files in the project.
+        """
 
     option_list = BaseCommand.option_list + (
         make_option('-f', '--force', action="store_true", default=False, dest='force',
